@@ -1,7 +1,7 @@
 var searchData=
 [
   ['saslanonymous',['SASLAnonymous',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a124eafd393640edc3a4860dd711c8e74',1,'QXmppConfiguration']]],
-  ['saslauthmechanism',['sASLAuthMechanism',['../classQXmppConfiguration.html#acf8e2a0bf51da53af72f1f689232082c',1,'QXmppConfiguration::sASLAuthMechanism() const '],['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11',1,'QXmppConfiguration::SASLAuthMechanism()']]],
+  ['saslauthmechanism',['SASLAuthMechanism',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11',1,'QXmppConfiguration::SASLAuthMechanism()'],['../classQXmppConfiguration.html#acf8e2a0bf51da53af72f1f689232082c',1,'QXmppConfiguration::sASLAuthMechanism() const ']]],
   ['sasldigestmd5',['SASLDigestMD5',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a84c03aaffee784130c781c74eca3c417',1,'QXmppConfiguration']]],
   ['saslplain',['SASLPlain',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a3a7552e191236404ed92c4208e119fc9',1,'QXmppConfiguration']]],
   ['saslxfacebookplatform',['SASLXFacebookPlatform',['../classQXmppConfiguration.html#afae07ce22ff50481eaa0ebff91c21d11a1b8a784020f8989ee89bba62a585ddff',1,'QXmppConfiguration']]],
@@ -11,12 +11,13 @@ var searchData=
   ['sendfile',['sendFile',['../classQXmppTransferManager.html#a35b5ec17e13b8f49ac2d29cec3d8b844',1,'QXmppTransferManager::sendFile(const QString &amp;jid, const QString &amp;filePath, const QString &amp;sid=QString())'],['../classQXmppTransferManager.html#a9e08182cdd6f2df3c2d3c19bb9660d24',1,'QXmppTransferManager::sendFile(const QString &amp;jid, QIODevice *device, const QXmppTransferFileInfo &amp;fileInfo, const QString &amp;sid=QString())']]],
   ['sendinvitation',['sendInvitation',['../classQXmppMucRoom.html#a94fbb2e103f48b5cc17661d25f47122e',1,'QXmppMucRoom']]],
   ['sendmessage',['sendMessage',['../classQXmppClient.html#a44d230e24954da4a05e661318494fce4',1,'QXmppClient::sendMessage()'],['../classQXmppMucRoom.html#a7a3ead69818cc6b2c8536384528dbada',1,'QXmppMucRoom::sendMessage()']]],
-  ['sendpacket',['sendPacket',['../classQXmppStream.html#a25cd6b70953cc482763fe96951323c10',1,'QXmppStream::sendPacket()'],['../classQXmppClient.html#ae1c78c51b831a69ee0369ec66ce98d6f',1,'QXmppClient::sendPacket()'],['../classQXmppServer.html#a7617374585f26e9a4b5c878cc81415d8',1,'QXmppServer::sendPacket()']]],
+  ['sendpacket',['sendPacket',['../classQXmppStream.html#a47473db930db0242bb2f6289172b6ea8',1,'QXmppStream::sendPacket()'],['../classQXmppClient.html#a28fb16fe7c83b134e46fea795bfffc35',1,'QXmppClient::sendPacket()'],['../classQXmppServer.html#a7617374585f26e9a4b5c878cc81415d8',1,'QXmppServer::sendPacket()']]],
   ['sentmessage',['SentMessage',['../classQXmppLogger.html#a932dbbd4f70a1e9c0ff8f452e61fc9b8ad1c7d954320b318802468a0655e81b42',1,'QXmppLogger']]],
   ['server',['server',['../classQXmppServerExtension.html#a56847ef0def13090d91cd6f6bded0aed',1,'QXmppServerExtension']]],
   ['serverreflexivetype',['ServerReflexiveType',['../classQXmppJingleCandidate.html#a6314b3ed7de59b68131db6ffab55fe7dadd47f88f0d90666a9b5768c70e407c7f',1,'QXmppJingleCandidate']]],
   ['set',['Set',['../classQXmppIq.html#a6bc7a0505a3be7309051ae2432a3d826a3dc74d347c7b00a2a1cd3b02b4cfd7b0',1,'QXmppIq']]],
   ['setaction',['setAction',['../classQXmppJingleIq.html#a7d3868e6bdc1b042f470a9ad795a811c',1,'QXmppJingleIq']]],
+  ['setactor',['setActor',['../classQXmppMucItem.html#a69f1abfed056c472a0e8539935328573',1,'QXmppMucItem']]],
   ['setaffiliation',['setAffiliation',['../classQXmppMucItem.html#ab1b1b9093c3bca933bd073a5ad9a4636',1,'QXmppMucItem']]],
   ['setarguments',['setArguments',['../classQXmppRpcInvokeIq.html#aea362ae92bbd8a29645751ffb5452d20',1,'QXmppRpcInvokeIq']]],
   ['setattentionrequested',['setAttentionRequested',['../classQXmppMessage.html#ad31b0fbbb7dd26ba8c6528a5d93a8a85',1,'QXmppMessage']]],
@@ -64,11 +65,13 @@ var searchData=
   ['setfields',['setFields',['../classQXmppDataForm.html#ac907784586541e0a79dd8d966e955f0f',1,'QXmppDataForm']]],
   ['setfirstname',['setFirstName',['../classQXmppVCardIq.html#a98b1ee2bf954f929777928791f7a53fe',1,'QXmppVCardIq']]],
   ['setform',['setForm',['../classQXmppMucOwnerIq.html#a02712467d300d6aad4213ddd7bff1bf2',1,'QXmppMucOwnerIq']]],
+  ['setformat',['setFormat',['../classQXmppVideoEncoder.html#af93109d87d4c00f24370dd6c5963fdb0',1,'QXmppVideoEncoder']]],
   ['setfoundation',['setFoundation',['../classQXmppJingleCandidate.html#aba966a89d765a54fbe15a453074c5bcd',1,'QXmppJingleCandidate']]],
   ['setfrom',['setFrom',['../classQXmppStanza.html#a320ae1faad87e443277a36260cefb85a',1,'QXmppStanza']]],
   ['setfullname',['setFullName',['../classQXmppVCardIq.html#a3f72cb68b4c2dc1120a3803d75b01b62',1,'QXmppVCardIq']]],
   ['setgroups',['setGroups',['../classQXmppRosterIq_1_1Item.html#ade2430a52808649b51ed9c6b554cf77a',1,'QXmppRosterIq::Item']]],
   ['sethost',['setHost',['../classQXmppJingleCandidate.html#a89f496aa65b0610af6c86c44120582aa',1,'QXmppJingleCandidate::setHost()'],['../classQXmppConfiguration.html#a97320e5239f46770edcd457301b41809',1,'QXmppConfiguration::setHost()']]],
+  ['seticecontrolling',['setIceControlling',['../classQXmppIceComponent.html#a679e8e78807464df76feed30495b7fe7',1,'QXmppIceComponent::setIceControlling()'],['../classQXmppIceConnection.html#a27972dd93469a303586e22cd4709b84e',1,'QXmppIceConnection::setIceControlling()']]],
   ['setid',['setId',['../classQXmppJinglePayloadType.html#a54a81639dc575b99cf4a42a24b7de65b',1,'QXmppJinglePayloadType::setId()'],['../classQXmppJingleCandidate.html#a1b92b6622dde36f6d8ad3f63138aba63',1,'QXmppJingleCandidate::setId()'],['../classQXmppPubSubItem.html#a0e3419b22bd11e146d99447c948e7014',1,'QXmppPubSubItem::setId()'],['../classQXmppStanza.html#aee06ffcdc8c7b7d67b2da536640e188d',1,'QXmppStanza::setId()']]],
   ['setignoresslerrors',['setIgnoreSslErrors',['../classQXmppConfiguration.html#af6075135d8735c7c6b95d7538a2c7245',1,'QXmppConfiguration']]],
   ['setinactivitytimeout',['setInactivityTimeout',['../classQXmppIncomingClient.html#ac2dc764e675d481d5afbe6e612765633',1,'QXmppIncomingClient']]],
@@ -106,8 +109,8 @@ var searchData=
   ['setnonsaslauthmechanism',['setNonSASLAuthMechanism',['../classQXmppConfiguration.html#a9dfd3f8b383c5996ff4906e5d3d62807',1,'QXmppConfiguration']]],
   ['setoptions',['setOptions',['../classQXmppDataForm_1_1Field.html#a08ff329fad506d69af660bfb9e4174fb',1,'QXmppDataForm::Field']]],
   ['setos',['setOs',['../classQXmppVersionIq.html#a8f6e8a6b8b02b98f99c12dfa8df78023',1,'QXmppVersionIq']]],
-  ['setparameters',['setParameters',['../classQXmppJinglePayloadType.html#a3c17aed60c502b37ada75ed8e7e256e0',1,'QXmppJinglePayloadType']]],
-  ['setpassword',['setPassword',['../classQXmppConfiguration.html#ab1deabbad52755bda2d975d5150dbf7a',1,'QXmppConfiguration::setPassword()'],['../classQXmppMucRoom.html#adfb1f258f106805c76bc501e8ea162f6',1,'QXmppMucRoom::setPassword()'],['../classQXmppPasswordReply.html#a11f9eccc067fc48dd09237499cccb53f',1,'QXmppPasswordReply::setPassword()']]],
+  ['setparameters',['setParameters',['../classQXmppVideoDecoder.html#a97338b2f599569651e9176d8a37542da',1,'QXmppVideoDecoder::setParameters()'],['../classQXmppJinglePayloadType.html#a3c17aed60c502b37ada75ed8e7e256e0',1,'QXmppJinglePayloadType::setParameters()']]],
+  ['setpassword',['setPassword',['../classQXmppConfiguration.html#ab1deabbad52755bda2d975d5150dbf7a',1,'QXmppConfiguration::setPassword()'],['../classQXmppMucRoom.html#adfb1f258f106805c76bc501e8ea162f6',1,'QXmppMucRoom::setPassword()'],['../classQXmppPasswordRequest.html#a81b68dceb87c75e0dbfe79cdb05dc426',1,'QXmppPasswordRequest::setPassword()'],['../classQXmppPasswordReply.html#a11f9eccc067fc48dd09237499cccb53f',1,'QXmppPasswordReply::setPassword()']]],
   ['setpasswordchecker',['setPasswordChecker',['../classQXmppIncomingClient.html#a6c2286e741e49b582db08b8ddbffe5cb',1,'QXmppIncomingClient::setPasswordChecker()'],['../classQXmppServer.html#ae797b5932a1fe33d234677deea4bf5ac',1,'QXmppServer::setPasswordChecker()']]],
   ['setpermissions',['setPermissions',['../classQXmppMucRoom.html#a7bef5394e4cd2af9c57f13fb4c8dadf7',1,'QXmppMucRoom']]],
   ['setphoto',['setPhoto',['../classQXmppVCardIq.html#a02fbd4d1b746daf9528ed60a14c586ac',1,'QXmppVCardIq']]],
@@ -123,10 +126,10 @@ var searchData=
   ['setqueryjid',['setQueryJid',['../classQXmppPubSubIq.html#a3baec6f49cf3be7cbe0aa674fd263a27',1,'QXmppPubSubIq']]],
   ['setquerynode',['setQueryNode',['../classQXmppPubSubIq.html#a4536330850f2ae8ef384062ee39f158c',1,'QXmppPubSubIq']]],
   ['setquerytype',['setQueryType',['../classQXmppPubSubIq.html#a67fecb1af8f3cc615abed963d9503752',1,'QXmppPubSubIq']]],
+  ['setreason',['setReason',['../classQXmppMucItem.html#ac4e4bf962ca2b6f5b14126938930434e',1,'QXmppMucItem']]],
   ['setreceiptid',['setReceiptId',['../classQXmppMessage.html#a104137c6a141edae8da9678fb07429eb',1,'QXmppMessage']]],
   ['setreceiptrequested',['setReceiptRequested',['../classQXmppMessage.html#a7ea77ae7738907a21a41d4dc3da767a6',1,'QXmppMessage']]],
   ['setreceived',['setReceived',['../classQXmppArchiveMessage.html#ad50506d533febb834db77813fb234389',1,'QXmppArchiveMessage']]],
-  ['setreconnectionmanager',['setReconnectionManager',['../classQXmppClient.html#ab1cdd29f5faeade87e097076125e6752',1,'QXmppClient']]],
   ['setremotepassword',['setRemotePassword',['../classQXmppIceComponent.html#a13d7b92269d4af812a19d042d6c1aceb',1,'QXmppIceComponent::setRemotePassword()'],['../classQXmppIceConnection.html#aafcb1ab8fd41cda479adba2f5da000f8',1,'QXmppIceConnection::setRemotePassword()']]],
   ['setremoteuser',['setRemoteUser',['../classQXmppIceComponent.html#a675c8f43d6d57cbe45e57efb557cd443',1,'QXmppIceComponent::setRemoteUser()'],['../classQXmppIceConnection.html#a57eadc3aad0a3f83eb697fa58612cd83',1,'QXmppIceConnection::setRemoteUser()']]],
   ['setrequired',['setRequired',['../classQXmppDataForm_1_1Field.html#aa1067cc412a7b39de116283e5bfcab2b',1,'QXmppDataForm::Field']]],
@@ -173,19 +176,20 @@ var searchData=
   ['signallogging',['SignalLogging',['../classQXmppLogger.html#a9a52fe426322ef8e10e05b7092be6c20ab2099e2e223040f603936071cc71b462',1,'QXmppLogger']]],
   ['size',['size',['../classQXmppVideoFrame.html#a1ea7f893dc931c3c32d9169a1f07be92',1,'QXmppVideoFrame']]],
   ['socket',['socket',['../classQXmppStream.html#acf771736ced3f18a0a763eb3b161b9c9',1,'QXmppStream::socket()'],['../classQXmppOutgoingClient.html#aca9b91ad84dc40275e4aa317f12ffa5c',1,'QXmppOutgoingClient::socket()']]],
-  ['socketerror',['SocketError',['../classQXmppClient.html#a7c2851d07cc33119752abc6ec8ffc47aac48e9688ca9dce21676283ada1172863',1,'QXmppClient::SocketError()'],['../classQXmppClient.html#a2b044b37ce88a2f2e65833b3d6e57a9f',1,'QXmppClient::socketError()']]],
+  ['socketerror',['socketError',['../classQXmppClient.html#a2b044b37ce88a2f2e65833b3d6e57a9f',1,'QXmppClient::socketError()'],['../classQXmppClient.html#a7c2851d07cc33119752abc6ec8ffc47aac48e9688ca9dce21676283ada1172863',1,'QXmppClient::SocketError()']]],
   ['socksmethod',['SocksMethod',['../classQXmppTransferJob.html#a962582d3049909305277e54e2095c71ba81571d8573b2003f6f3a66fcda644815',1,'QXmppTransferJob']]],
   ['speed',['speed',['../classQXmppTransferJob.html#ad4a631dda697f59eb03bf373aeddf6a6',1,'QXmppTransferJob']]],
   ['stamp',['stamp',['../classQXmppMessage.html#a75532528f320e94dc030f4a6e7ea9fbc',1,'QXmppMessage']]],
+  ['stanzas',['Stanzas',['../group__Stanzas.html',1,'']]],
   ['start',['start',['../classQXmppArchiveChat.html#a92f75a9737deb2ce322c2767634ab935',1,'QXmppArchiveChat::start()'],['../classQXmppArchiveListIq.html#abc3a47af035fd370e193e4fedac525f3',1,'QXmppArchiveListIq::start()'],['../classQXmppArchiveRemoveIq.html#afee3c666048c4cb211753e3dc0a54822',1,'QXmppArchiveRemoveIq::start()'],['../classQXmppArchiveRetrieveIq.html#ac8d0606440dd22b189e48521b50e46d1',1,'QXmppArchiveRetrieveIq::start()'],['../classQXmppServerExtension.html#a5341d9bb242ac64b996a35219eac1679',1,'QXmppServerExtension::start()']]],
   ['startstate',['StartState',['../classQXmppTransferJob.html#aab5bb06ca0d2c4f1fac33b7012d1c14faab96ac5cd1310e66c6048512f0846d66',1,'QXmppTransferJob']]],
   ['starttone',['startTone',['../classQXmppRtpAudioChannel.html#a70b63c9ec09cc6d2a39403e4b680581a',1,'QXmppRtpAudioChannel']]],
   ['startvideo',['startVideo',['../classQXmppCall.html#a08cfa042104fbdd80019c38670cd02b2',1,'QXmppCall']]],
-  ['state',['State',['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099a',1,'QXmppMessage::State()'],['../classQXmppCall.html#a90205b5034613127d2c4adc6a0252759',1,'QXmppCall::State()'],['../classQXmppClient.html#a5f4e70d508c08967f72fd41c5343ad2e',1,'QXmppClient::State()'],['../classQXmppTransferJob.html#aab5bb06ca0d2c4f1fac33b7012d1c14f',1,'QXmppTransferJob::State()'],['../classQXmppCall.html#aa09971e040121ffef56577a537be35a1',1,'QXmppCall::state()'],['../classQXmppClient.html#ac4cbb2e04e5ca683fadbc79ef173f0a5',1,'QXmppClient::state()'],['../classQXmppTransferJob.html#a51e1adb470053f12c5d5b2a10887c8f3',1,'QXmppTransferJob::state()'],['../classQXmppMessage.html#af90654a174ae92bb7904ed01b4d81dc4',1,'QXmppMessage::state()']]],
+  ['state',['state',['../classQXmppCall.html#aa09971e040121ffef56577a537be35a1',1,'QXmppCall::state()'],['../classQXmppClient.html#ac4cbb2e04e5ca683fadbc79ef173f0a5',1,'QXmppClient::state()'],['../classQXmppTransferJob.html#a51e1adb470053f12c5d5b2a10887c8f3',1,'QXmppTransferJob::state()'],['../classQXmppMessage.html#af90654a174ae92bb7904ed01b4d81dc4',1,'QXmppMessage::state() const '],['../classQXmppMessage.html#aeaa3cc5ccb7d451067a80dd1f3c7099a',1,'QXmppMessage::State()'],['../classQXmppCall.html#a90205b5034613127d2c4adc6a0252759',1,'QXmppCall::State()'],['../classQXmppClient.html#a5f4e70d508c08967f72fd41c5343ad2e',1,'QXmppClient::State()'],['../classQXmppTransferJob.html#aab5bb06ca0d2c4f1fac33b7012d1c14f',1,'QXmppTransferJob::State()']]],
   ['statechanged',['stateChanged',['../classQXmppCall.html#a16dd6c41d04900e322ce522d010cd513',1,'QXmppCall::stateChanged()'],['../classQXmppClient.html#a8bd2617265568c9769a8ba608a4ff05d',1,'QXmppClient::stateChanged()'],['../classQXmppTransferJob.html#a040ea186f586a3a9ffbc6e52b3cd3917',1,'QXmppTransferJob::stateChanged()']]],
   ['statistics',['statistics',['../classQXmppServer.html#ab0453751b0aab88ff0cbd2cc26d9a42d',1,'QXmppServer::statistics()'],['../classQXmppServerExtension.html#a7ed5df89f8ff04b67e7bf094d9d84461',1,'QXmppServerExtension::statistics()']]],
+  ['status',['status',['../classQXmppPresence.html#a4ff79a31cc601e78ff05b6e5427093f4',1,'QXmppPresence::status()'],['../classQXmppPresence.html#a05d24001697e6dbb52962a7e66e0b221',1,'QXmppPresence::status() const '],['../classQXmppPresence_1_1Status.html#a037810a12b5682622f868bef7cbdcfca',1,'QXmppPresence::Status::Status()']]],
   ['status',['Status',['../classQXmppPresence_1_1Status.html',1,'QXmppPresence']]],
-  ['status',['Status',['../classQXmppPresence_1_1Status.html#a037810a12b5682622f868bef7cbdcfca',1,'QXmppPresence::Status::Status()'],['../classQXmppPresence.html#a4ff79a31cc601e78ff05b6e5427093f4',1,'QXmppPresence::status()'],['../classQXmppPresence.html#a05d24001697e6dbb52962a7e66e0b221',1,'QXmppPresence::status() const ']]],
   ['statustext',['statusText',['../classQXmppPresence_1_1Status.html#a19efb38866b3bb10a465b71a8d19d973',1,'QXmppPresence::Status']]],
   ['stdoutlogging',['StdoutLogging',['../classQXmppLogger.html#a9a52fe426322ef8e10e05b7092be6c20acd51c8c54ebb5284752f224c69709998',1,'QXmppLogger']]],
   ['stop',['stop',['../classQXmppServerExtension.html#acbf4204a0bf898e70bf3e2fdceae6b09',1,'QXmppServerExtension']]],
@@ -196,7 +200,7 @@ var searchData=
   ['subjectaction',['SubjectAction',['../classQXmppMucRoom.html#acd3129293f69d7e7cdd91b65aae0606fa1b691dc1004e867aa844ba380bb383ad',1,'QXmppMucRoom']]],
   ['subjectchanged',['subjectChanged',['../classQXmppMucRoom.html#a3ebda02e7b225cf6bdc264290c40b5a7',1,'QXmppMucRoom']]],
   ['submit',['Submit',['../classQXmppDataForm.html#adab12c436b8c450e2b4f59da1aecadeeae6ab517a99b8c387056bd5d341de4082',1,'QXmppDataForm']]],
-  ['subscribe',['Subscribe',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da27a106dd1fc50ecdba0ad9b95307ce62',1,'QXmppPresence::Subscribe()'],['../classQXmppRosterManager.html#a866dbaaf87840ae04f5f44532aa7ccc0',1,'QXmppRosterManager::subscribe()']]],
+  ['subscribe',['subscribe',['../classQXmppRosterManager.html#a866dbaaf87840ae04f5f44532aa7ccc0',1,'QXmppRosterManager::subscribe()'],['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da27a106dd1fc50ecdba0ad9b95307ce62',1,'QXmppPresence::Subscribe()']]],
   ['subscribed',['Subscribed',['../classQXmppPresence.html#a47ab8dd08436f9d7c90d2990678b5a6da59304e64fb15ce69c9395f6d217dcb6b',1,'QXmppPresence']]],
   ['subscriptionid',['subscriptionId',['../classQXmppPubSubIq.html#adb11498556fe6f224a50caa10e7a2e18',1,'QXmppPubSubIq']]],
   ['subscriptionreceived',['subscriptionReceived',['../classQXmppRosterManager.html#a3407f699aded8ed2724cdbb121678c4a',1,'QXmppRosterManager']]],
