@@ -1,6 +1,8 @@
 var searchData=
 [
   ['handleelement',['handleElement',['../classQXmppServer.html#ab7ee638bc69fd4ca76638e45a64c6ec4',1,'QXmppServer']]],
+  ['handleframe',['handleFrame',['../classQXmppVideoEncoder.html#a8c7b14c4bbefcfab6916988033c1fad8',1,'QXmppVideoEncoder']]],
+  ['handlepacket',['handlePacket',['../classQXmppVideoDecoder.html#adc454869b3572ca8248996247e2da84f',1,'QXmppVideoDecoder']]],
   ['handlestanza',['handleStanza',['../classQXmppStream.html#aeb24cc2f3b30c902f0a6e3be9586510d',1,'QXmppStream::handleStanza()'],['../classQXmppClientExtension.html#af026d292204dc538249d16086e9e8108',1,'QXmppClientExtension::handleStanza()'],['../classQXmppServerExtension.html#ad8218187cd17b9d730fc72a9d722cf0a',1,'QXmppServerExtension::handleStanza()']]],
   ['handlestart',['handleStart',['../classQXmppStream.html#a970b0a6893c097c03ff6d279234178d5',1,'QXmppStream']]],
   ['handlestream',['handleStream',['../classQXmppStream.html#adda64f130a59719e241eea89b31c27fe',1,'QXmppStream']]],
