@@ -2,6 +2,10 @@ var searchData=
 [
   ['jid',['jid',['../classQXmppBindIq.html#a97457e48e85c2ffb620934ddcc5fcd34',1,'QXmppBindIq::jid()'],['../classQXmppBookmarkConference.html#a651e92afc55ffd7901a79d007797c90f',1,'QXmppBookmarkConference::jid()'],['../classQXmppMucItem.html#aa8852e37e3adb422dde9f46289c3a3c8',1,'QXmppMucItem::jid()'],['../classQXmppConfiguration.html#a9733276982f4b55517e4ea739d7039a2',1,'QXmppConfiguration::jid()'],['../classQXmppIncomingClient.html#ab708ff1b465b52bb93e12941bca38486',1,'QXmppIncomingClient::jid()']]],
   ['jidbare',['jidBare',['../classQXmppConfiguration.html#a00c6b1ca3a1008f214f0258f6736c9ba',1,'QXmppConfiguration']]],
+  ['jidtobarejid',['jidToBareJid',['../classQXmppUtils.html#ab3d6904c272008e64c86107221f0936e',1,'QXmppUtils']]],
+  ['jidtodomain',['jidToDomain',['../classQXmppUtils.html#a8723c0bee318896100ab2f41ae4cd73e',1,'QXmppUtils']]],
+  ['jidtoresource',['jidToResource',['../classQXmppUtils.html#a5248b98f6df1ba1aae3f416092819443',1,'QXmppUtils']]],
+  ['jidtouser',['jidToUser',['../classQXmppUtils.html#a0df11be63c49dc312e417cddca3fa3e5',1,'QXmppUtils']]],
   ['jobfinished',['jobFinished',['../classQXmppTransferManager.html#af2dcae40840d04530e5aef97a6586188',1,'QXmppTransferManager']]],
   ['jobstarted',['jobStarted',['../classQXmppTransferManager.html#a2a19e77348fe9df618d7e289bbe84f21',1,'QXmppTransferManager']]],
   ['join',['join',['../classQXmppMucRoom.html#afd01483eb367ecfa4f1fc2828919b4c1',1,'QXmppMucRoom']]],
