@@ -2,6 +2,8 @@ var searchData=
 [
   ['thread',['thread',['../classQXmppArchiveChat.html#a4fa81fab978ec0725006761e81c2458c',1,'QXmppArchiveChat::thread()'],['../classQXmppMessage.html#a048b9b4a4d768e00dd54d731678ae6b1',1,'QXmppMessage::thread()']]],
   ['timereceived',['timeReceived',['../classQXmppEntityTimeManager.html#a43bf87be2b6c3291980779148f10ef25',1,'QXmppEntityTimeManager']]],
+  ['timezoneoffsetfromstring',['timezoneOffsetFromString',['../classQXmppUtils.html#affdf229e846c999ea8d3f464d8e154a9',1,'QXmppUtils']]],
+  ['timezoneoffsettostring',['timezoneOffsetToString',['../classQXmppUtils.html#ad44b0a2537afd21c426483e3daeca5d8',1,'QXmppUtils']]],
   ['title',['title',['../classQXmppDataForm.html#a224b4f313340a5f2aa2f8cf97ec8032b',1,'QXmppDataForm']]],
   ['to',['to',['../classQXmppStanza.html#a45ab4c2f04d712ee93df5d0e4b2c03a4',1,'QXmppStanza']]],
   ['tostring',['toString',['../classQXmppRtpPacket.html#a166ac10ac60f1d1cdabba66fcd90985b',1,'QXmppRtpPacket']]],
