@@ -33,7 +33,6 @@
 #include "QXmppPresence.h"
 #include "QXmppMessage.h"
 #include "QXmppUtils.h"
-#include "QXmppReconnectionManager.h"
 #include "QXmppVCardManager.h"
 
 #include <QMovie>
@@ -159,14 +158,7 @@ mainDialog::mainDialog(QWidget *parent): QDialog(parent, Qt::Window),
     check = connect(&m_xmppClient, SIGNAL(connected()), SLOT(addAccountToCache()));
     Q_ASSERT(check);
 
-    check = connect(m_xmppClient.reconnectionManager(),
-                    SIGNAL(reconnectingIn(int)),
-                    SLOT(showSignInPageForAutoReconnection(int)));
-    Q_ASSERT(check);
-
-    check = connect(m_xmppClient.reconnectionManager(),
-                    SIGNAL(reconnectingNow()),
-                    SLOT(showSignInPageForAutoReconnectionNow()));
+    check = connect(&m_xmppClient, SIGNAL(disconnected()), SLOT(showSignInPageAfterUserDisconnection()));
     Q_ASSERT(check);
 
     check = connect(&m_xmppClient.vCardManager(),
@@ -347,7 +339,7 @@ chatDialog* mainDialog::getChatDialog(const QString& bareJid)
             m_chatDlgsList[bareJid]->setDisplayName(m_rosterItemModel.
                                                 getRosterItemFromBareJid(bareJid)->getName());
         else
-            m_chatDlgsList[bareJid]->setDisplayName(jidToUser(bareJid));
+            m_chatDlgsList[bareJid]->setDisplayName(QXmppUtils::jidToUser(bareJid));
 
         m_chatDlgsList[bareJid]->setQXmppClient(&m_xmppClient);
     }
@@ -364,8 +356,8 @@ void mainDialog::showChatDialog(const QString& bareJid)
 void mainDialog::messageReceived(const QXmppMessage& msg)
 {
     QString from = msg.from();
-    getChatDialog(jidToBareJid(from))->show();
-    getChatDialog(jidToBareJid(from))->messageReceived(msg.body());
+    getChatDialog(QXmppUtils::jidToBareJid(from))->show();
+    getChatDialog(QXmppUtils::jidToBareJid(from))->messageReceived(msg.body());
 }
 
 void mainDialog::statusTextChanged(const QString& status)
@@ -381,7 +373,6 @@ void mainDialog::presenceTypeChanged(QXmppPresence::Type presenceType)
     if(presenceType == QXmppPresence::Unavailable)
     {
         m_xmppClient.disconnectFromServer();
-        showSignInPageAfterUserDisconnection();
     }
     else if(presenceType == QXmppPresence::Available)
     {
@@ -474,7 +465,6 @@ void mainDialog::cancelSignIn()
         ui->lineEdit_password->setText("");
 
     ui->label_throbber->hide();
-    m_xmppClient.reconnectionManager()->cancelReconnection();
     m_xmppClient.disconnectFromServer();
     showSignInPage();
     showLoginStatus("Sign in cancelled");
@@ -503,30 +493,6 @@ void mainDialog::showSignInPageAfterUserDisconnection()
     showSignInPage();
 }
 
-void mainDialog::showSignInPageForAutoReconnection(int i)
-{
-    ui->label_throbber->hide();
-    ui->pushButton_signIn->setDisabled(true);
-    ui->pushButton_cancel->setDisabled(false);
-    ui->lineEdit_userName->setDisabled(true);
-    ui->lineEdit_password->setDisabled(true);
-    ui->checkBox_rememberPasswd->setDisabled(true);
-    showLoginStatusWithCounter(QString("Reconnecting in %1 sec..."), i);
-    ui->stackedWidget->setCurrentIndex(1);
-}
-
-void mainDialog::showSignInPageForAutoReconnectionNow()
-{
-    ui->label_throbber->show();
-    ui->pushButton_signIn->setDisabled(true);
-    ui->pushButton_cancel->setDisabled(false);
-    ui->lineEdit_userName->setDisabled(true);
-    ui->lineEdit_password->setDisabled(true);
-    ui->checkBox_rememberPasswd->setDisabled(true);
-    showLoginStatusWithProgress(QString("Connecting"));
-    ui->stackedWidget->setCurrentIndex(1);
-}
-
 void mainDialog::showRosterPage()
 {
     ui->stackedWidget->setCurrentIndex(0);
@@ -634,7 +600,6 @@ void mainDialog::addAccountToCache()
 void mainDialog::action_signOut()
 {
     m_xmppClient.disconnectFromServer();
-    showSignInPageAfterUserDisconnection();
 
     // update widget
     m_statusWidget.setStatusText(
