@@ -28,8 +28,8 @@
 echoClient::echoClient(QObject *parent)
     : QXmppClient(parent)
 {
-    bool check = connect(this, SIGNAL(messageReceived(const QXmppMessage&)),
-        SLOT(messageReceived(const QXmppMessage&)));
+    bool check = connect(this, SIGNAL(messageReceived(QXmppMessage)),
+        SLOT(messageReceived(QXmppMessage)));
     Q_ASSERT(check);
     Q_UNUSED(check);
 }
