@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2011 The QXmpp developers
  *
  * Author:
  *	Ian Reinhart Geiser
@@ -44,6 +44,6 @@ int main(int argc, char *argv[])
     const QString username = (!strcmp(argv[1], "send")) ? QLatin1String("qxmpp.test1") : QLatin1String("qxmpp.test2");
 
     xmppClient client;
-    client.connectToServer("talk.google.com", username, "qxmpp123", "gmail.com");
+    client.connectToServer(username + "@gmail.com", "qxmpp123");
     return a.exec();
 }
