@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2011 The QXmpp developers
  *
  * Author:
  *	Ian Reinhart Geiser
@@ -25,10 +25,9 @@
 #ifndef XMPPCLIENT_H
 #define XMPPCLIENT_H
 
+#include "QXmppCallManager.h"
 #include "QXmppClient.h"
 
-class QXmppCall;
-
 class xmppClient : public QXmppClient
 {
     Q_OBJECT
@@ -37,10 +36,13 @@ public:
     xmppClient(QObject *parent = 0);
 
 private slots:
+    void slotAudioModeChanged(QIODevice::OpenMode mode);
     void slotCallReceived(QXmppCall *call);
-    void slotConnected();
-    void slotFinished();
+    void slotCallStateChanged(QXmppCall::State state);
     void slotPresenceReceived(const QXmppPresence &presence);
+
+private:
+    QXmppCallManager *callManager;
 };
 
 #endif // IBBCLIENT_H
