@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2011 The QXmpp developers
  *
  * Author:
  *	Ian Reinhart Geiser
@@ -33,7 +33,6 @@ int main(int argc, char *argv[])
     QXmppLogger::getLogger()->setLoggingType(QXmppLogger::StdoutLogging);
 
     rpcClient client;
-    client.configuration().setUseSASLAuthentication( false );
-    client.connectToServer("jabber.geiseri.com", "client", "Passw0rd", "geiseri.com");
+    client.connectToServer("qxmpp.test2@gmail.com", "qxmpp123");
     return a.exec();
 }
