@@ -1,8 +1,9 @@
 /*
- * Copyright (C) 2008-2010 The QXmpp developers
+ * Copyright (C) 2008-2011 The QXmpp developers
  *
- * Author:
+ * Authors:
  *	Ian Reinhart Geiser
+ *	Jeremy Lainé
  *
  * Source:
  *	http://code.google.com/p/qxmpp
@@ -27,6 +28,8 @@
 
 #include "QXmppClient.h"
 
+class QXmppRpcManager;
+
 class rpcClient : public QXmppClient
 {
     Q_OBJECT
@@ -35,12 +38,13 @@ public:
     rpcClient(QObject *parent = 0);
     ~rpcClient();
 
-public slots:
-    void isConnected();
-    void invokeRemoteMethod();
-    void result(const QVariant &value );
-    void error( int code, const QString &message );
+private slots:
+    void slotInvokeRemoteMethod();
+    void slotPresenceReceived(const QXmppPresence &presence);
 
+private:
+    QString m_remoteJid;
+    QXmppRpcManager *m_rpcManager;
 };
 
 #endif // RPCCLIENT_H
