@@ -29,12 +29,14 @@
 #include <QUrl>
 #include <QXmlStreamWriter>
 
+#include "QXmppGlobal.h"
+
 class QDomElement;
 
 /// \brief The QXmppBookmarkConference class represents a bookmark for a conference room,
 /// as defined by XEP-0048: Bookmarks.
 ///
-class QXmppBookmarkConference
+class QXMPP_EXPORT QXmppBookmarkConference
 {
 public:
     QXmppBookmarkConference();
@@ -61,7 +63,7 @@ private:
 /// \brief The QXmppBookmarkUrl class represents a bookmark for a web page,
 /// as defined by XEP-0048: Bookmarks.
 ///
-class QXmppBookmarkUrl
+class QXMPP_EXPORT QXmppBookmarkUrl
 {
 public:
     QString name() const;
@@ -78,7 +80,7 @@ private:
 /// \brief The QXmppbookmarkSets class represents a set of bookmarks, as defined
 /// by XEP-0048: Bookmarks.
 ///
-class QXmppBookmarkSet
+class QXMPP_EXPORT QXmppBookmarkSet
 {
 public:
     QList<QXmppBookmarkConference> conferences() const;
