@@ -102,7 +102,7 @@ static qint16 search(qint16 val, qint16 *table, qint16 size)
  * For further information see John C. Bellamy's Digital Telephony, 1982,
  * John Wiley & Sons, pps 98-111 and 472-476.
  */
-quint8 linear2alaw(qint16 pcm_val)
+static quint8 linear2alaw(qint16 pcm_val)
 {
    qint16 mask;
    qint16 seg;
@@ -138,7 +138,7 @@ quint8 linear2alaw(qint16 pcm_val)
  * alaw2linear() - Convert an A-law value to 16-bit linear PCM
  *
  */
-qint16 alaw2linear(quint8 a_val)
+static qint16 alaw2linear(quint8 a_val)
 {
    qint16 t;
    qint16 seg;
@@ -190,7 +190,7 @@ qint16 alaw2linear(quint8 a_val)
  * For further information see John C. Bellamy's Digital Telephony, 1982,
  * John Wiley & Sons, pps 98-111 and 472-476.
  */
-quint8 linear2ulaw(qint16 pcm_val)
+static quint8 linear2ulaw(qint16 pcm_val)
 {
    qint16 mask;
    qint16 seg;
@@ -231,7 +231,7 @@ quint8 linear2ulaw(qint16 pcm_val)
  * Note that this function expects to be passed the complement of the
  * original code word. This is in keeping with ISDN conventions.
  */
-qint16 ulaw2linear(quint8 u_val)
+static qint16 ulaw2linear(quint8 u_val)
 {
    qint16 t;
 
@@ -248,6 +248,24 @@ qint16 ulaw2linear(quint8 u_val)
    return ((u_val & SIGN_BIT) ? (BIAS - t) : (t - BIAS));
 }
 
+/// Destroys an audio codec.
+
+QXmppCodec::~QXmppCodec()
+{
+}
+
+/// Destroys a video decoder.
+
+QXmppVideoDecoder::~QXmppVideoDecoder()
+{
+}
+
+/// Destroys a video encoder.
+
+QXmppVideoEncoder::~QXmppVideoEncoder()
+{
+}
+
 QXmppG711aCodec::QXmppG711aCodec(int clockrate)
 {
     m_frequency = clockrate;
