@@ -27,6 +27,16 @@
 
 #include <QString>
 
+#if defined(QXMPP_STATIC)
+#  define QXMPP_EXPORT
+#else
+#  if defined(QXMPP_BUILD)
+#    define QXMPP_EXPORT Q_DECL_EXPORT
+#  else
+#    define QXMPP_EXPORT Q_DECL_IMPORT
+#  endif
+#endif
+
 /// This macro expands a numeric value of the form 0xMMNNPP (MM =
 /// major, NN = minor, PP = patch) that specifies QXmpp's version
 /// number. For example, if you compile your application against
@@ -36,8 +46,8 @@
 /// available.
 ///
 
-#define QXMPP_VERSION 0x00035c
+#define QXMPP_VERSION 0x00045c
 
-QString QXmppVersion();
+QXMPP_EXPORT QString QXmppVersion();
 
 #endif //QXMPPGLOBAL_H
