@@ -31,7 +31,7 @@
 /// \brief The QXmppPresence class represents an XMPP presence stanza.
 ///
 /// \ingroup Stanzas
-class QXmppPresence : public QXmppStanza
+class QXMPP_EXPORT QXmppPresence : public QXmppStanza
 {
 public:
     /// This enum is used to describe a presence type.
@@ -47,7 +47,8 @@ public:
         Probe           ///< A request for an entity's current presence; SHOULD be generated only by a server on behalf of a user.
     };
 
-    // XEP-0153: vCard-Based Avatars
+    /// This enum is used to describe vCard updates as defined by
+    /// XEP-0153: vCard-Based Avatars
     enum VCardUpdateType
     {
         VCardUpdateNone = 0,    ///< Protocol is not supported
@@ -64,7 +65,7 @@ public:
     /// It stores information such as the "away", "busy" status of a user, or
     /// a human-readable description.
 
-    class Status
+    class QXMPP_EXPORT Status
     {
     public:
         /// This enum is used to describe an availability status.
