@@ -307,9 +307,7 @@ QXmppCodec *QXmppRtpAudioChannelPrivate::codecForPayloadType(const QXmppJinglePa
     return 0;
 }
 
-/// Creates a new RTP audio channel.
-///
-/// \param parent
+/// Constructs a new RTP audio channel with the given \a parent.
 
 QXmppRtpAudioChannel::QXmppRtpAudioChannel(QObject *parent)
     : QIODevice(parent)
@@ -373,7 +371,7 @@ QXmppRtpAudioChannel::~QXmppRtpAudioChannel()
 
 qint64 QXmppRtpAudioChannel::bytesAvailable() const
 {
-    return d->incomingBuffer.size();
+    return QIODevice::bytesAvailable() + d->incomingBuffer.size();
 }
 
 /// Closes the RTP channel.
@@ -490,6 +488,8 @@ bool QXmppRtpAudioChannel::isSequential() const
     return true;
 }
 
+/// Returns the mode in which the channel has been opened.
+
 QIODevice::OpenMode QXmppRtpAudioChannel::openMode() const
 {
     return QIODevice::openMode();
@@ -767,32 +767,36 @@ QXmppVideoFrame::QXmppVideoFrame(int bytes, const QSize &size, int bytesPerLine,
     m_data.resize(bytes);
 }
 
+/// Returns a pointer to the start of the frame data buffer.
+
 uchar *QXmppVideoFrame::bits()
 {
     return (uchar*)m_data.data();
 }
 
+/// Returns a pointer to the start of the frame data buffer.
+
 const uchar *QXmppVideoFrame::bits() const
 {
     return (const uchar*)m_data.constData();
 }
 
-/** Returns the number of bytes in a scan line.
- */
+/// Returns the number of bytes in a scan line.
+
 int QXmppVideoFrame::bytesPerLine() const
 {
     return m_bytesPerLine;
 }
 
-/** Returns the height of a video frame.
- */
+/// Returns the height of a video frame.
+
 int QXmppVideoFrame::height() const
 {
     return m_height;
 }
 
-/** Returns true if the frame is valid.
- */
+/// Returns true if the frame is valid.
+
 bool QXmppVideoFrame::isValid() const
 {
     return m_pixelFormat != Format_Invalid &&
@@ -800,29 +804,29 @@ bool QXmppVideoFrame::isValid() const
            m_mappedBytes > 0;
 }
 
-/** Returns the number of bytes occupied by the mapped frame data.
- */
+/// Returns the number of bytes occupied by the mapped frame data.
+
 int QXmppVideoFrame::mappedBytes() const
 {
     return m_mappedBytes;
 }
 
-/** Returns the color format of a video frame.
- */
+/// Returns the color format of a video frame.
+
 QXmppVideoFrame::PixelFormat QXmppVideoFrame::pixelFormat() const
 {
     return m_pixelFormat;
 }
 
-/** Returns the size of a video frame.
- */
+/// Returns the size of a video frame.
+
 QSize QXmppVideoFrame::size() const
 {
     return QSize(m_width, m_height);
 }
 
-/** Returns the width of a video frame.
- */
+/// Returns the width of a video frame.
+
 int QXmppVideoFrame::width() const
 {
     return m_width;
@@ -854,6 +858,8 @@ QXmppRtpVideoChannelPrivate::QXmppRtpVideoChannelPrivate()
     outgoingSsrc = qrand();
 }
 
+/// Constructs a new RTP video channel with the given \a parent.
+
 QXmppRtpVideoChannel::QXmppRtpVideoChannel(QObject *parent)
     : QXmppLoggable(parent)
 {
@@ -948,6 +954,8 @@ void QXmppRtpVideoChannel::setEncoderFormat(const QXmppVideoFormat &format)
     d->outgoingFormat = format;
 }
 
+/// Returns the mode in which the channel has been opened.
+
 QIODevice::OpenMode QXmppRtpVideoChannel::openMode() const
 {
     QIODevice::OpenMode mode = QIODevice::NotOpen;
@@ -1009,6 +1017,8 @@ void QXmppRtpVideoChannel::payloadTypesChanged()
     }
 }
 
+/// Decodes buffered RTP packets and returns a list of video frames.
+
 QList<QXmppVideoFrame> QXmppRtpVideoChannel::readFrames()
 {
     const QList<QXmppVideoFrame> frames = d->frames;
@@ -1016,6 +1026,8 @@ QList<QXmppVideoFrame> QXmppRtpVideoChannel::readFrames()
     return frames;
 }
 
+/// Encodes a video \a frame and sends RTP packets.
+
 void QXmppRtpVideoChannel::writeFrame(const QXmppVideoFrame &frame)
 {
     if (!d->encoder) {
