@@ -25,7 +25,7 @@
 
 #include "QXmppConstants.h"
 #include "QXmppLogger.h"
-#include "QXmppPacket.h"
+#include "QXmppStanza.h"
 #include "QXmppStream.h"
 #include "QXmppUtils.h"
 
@@ -130,7 +130,7 @@ bool QXmppStream::sendData(const QByteArray &data)
 ///
 /// \param packet
 
-bool QXmppStream::sendPacket(const QXmppPacket &packet)
+bool QXmppStream::sendPacket(const QXmppStanza &packet)
 {
     // prepare packet
     QByteArray data;
@@ -216,6 +216,12 @@ void QXmppStream::_q_socketReadyRead()
 {
     d->dataBuffer.append(d->socket->readAll());
 
+    // handle whitespace pings
+    if (!d->dataBuffer.isEmpty() && d->dataBuffer.trimmed().isEmpty()) {
+        d->dataBuffer.clear();
+        handleStanza(QDomElement());
+    }
+
     // FIXME : maybe these QRegExps could be static?
     QRegExp startStreamRegex("^(<\\?xml.*\\?>)?\\s*<stream:stream.*>");
     startStreamRegex.setMinimal(true);
