@@ -26,8 +26,13 @@
 #define QXMPPCONFIGURATION_H
 
 #include <QString>
-#include <QNetworkProxy>
-#include <QSslCertificate>
+#include <QSharedDataPointer>
+
+#include "QXmppGlobal.h"
+
+class QNetworkProxy;
+class QSslCertificate;
+class QXmppConfigurationPrivate;
 
 /// \brief The QXmppConfiguration class holds configuration options.
 ///
@@ -40,7 +45,7 @@
 /// etc..
 ///
 
-class QXmppConfiguration
+class QXMPP_EXPORT QXmppConfiguration
 {
 public:
     /// An enumeration for type of the Security Mode that is stream is encrypted or not.
@@ -82,7 +87,9 @@ public:
     };
 
     QXmppConfiguration();
+    QXmppConfiguration(const QXmppConfiguration &other);
     ~QXmppConfiguration();
+    QXmppConfiguration& operator=(const QXmppConfiguration &other);
 
     QString host() const;
     void setHost(const QString&);
@@ -147,43 +154,7 @@ public:
     void setCaCertificates(const QList<QSslCertificate> &);
 
 private:
-    QString m_host;
-    int m_port;
-    QString m_user;
-    QString m_password;
-    QString m_domain;
-    QString m_resource;
-
-    // Facebook
-    QString m_facebookAccessToken;
-    QString m_facebookAppId;
-
-    // default is false
-    bool m_autoAcceptSubscriptions;
-    // default is true
-    bool m_sendIntialPresence;
-    // default is true
-    bool m_sendRosterRequest;
-    // interval in seconds, if zero won't ping
-    int m_keepAliveInterval;
-    // interval in seconds, if zero won't timeout
-    int m_keepAliveTimeout;
-    // will keep reconnecting if disconnected, default is true
-    bool m_autoReconnectionEnabled;
-    bool m_useSASLAuthentication; ///< flag to specify what authentication system
-                                  ///< to be used
-                                ///< defualt is true and use SASL
-                                ///< false would use NonSASL if available
-    // default is true
-    bool m_ignoreSslErrors;
-
-    StreamSecurityMode m_streamSecurityMode;
-    NonSASLAuthMechanism m_nonSASLAuthMechanism;
-    SASLAuthMechanism m_SASLAuthMechanism;
-
-    QNetworkProxy m_networkProxy;
-
-    QList<QSslCertificate> m_caCertificates;
+    QSharedDataPointer<QXmppConfigurationPrivate> d;
 };
 
 #endif // QXMPPCONFIGURATION_H
