@@ -111,7 +111,8 @@ QStringList QXmppMucManager::discoveryFeatures() const
         << ns_muc
         << ns_muc_admin
         << ns_muc_owner
-        << ns_muc_user;
+        << ns_muc_user
+        << ns_conference;
 }
 
 bool QXmppMucManager::handleStanza(const QDomElement &element)
@@ -260,7 +261,7 @@ bool QXmppMucRoom::join()
         p.setValue(d->password);
         x.appendChild(p);
     }
-    packet.setExtensions(x);
+    packet.setExtensions(QXmppElementList() << x);
     return d->client->sendPacket(packet);
 }
 
@@ -274,7 +275,7 @@ bool QXmppMucRoom::join()
 bool QXmppMucRoom::kick(const QString &jid, const QString &reason)
 {
     QXmppMucItem item;
-    item.setNick(jidToResource(jid));
+    item.setNick(QXmppUtils::jidToResource(jid));
     item.setRole(QXmppMucItem::NoRole);
     item.setReason(reason);
 
@@ -329,7 +330,7 @@ bool QXmppMucRoom::sendInvitation(const QString &jid, const QString &reason)
     QXmppMessage message;
     message.setTo(jid);
     message.setType(QXmppMessage::Normal);
-    message.setExtensions(x);
+    message.setExtensions(QXmppElementList() << x);
     return d->client->sendPacket(message);
 }
 
@@ -548,7 +549,7 @@ void QXmppMucRoom::_q_disconnected()
 
 void QXmppMucRoom::_q_messageReceived(const QXmppMessage &message)
 {
-    if (jidToBareJid(message.from())!= d->jid)
+    if (QXmppUtils::jidToBareJid(message.from())!= d->jid)
         return;
 
     // handle message subject
@@ -572,7 +573,7 @@ void QXmppMucRoom::_q_presenceReceived(const QXmppPresence &presence)
         d->client->sendPacket(packet);
     }
 
-    if (jidToBareJid(jid) != d->jid)
+    if (QXmppUtils::jidToBareJid(jid) != d->jid)
         return;
 
     if (presence.type() == QXmppPresence::Available) {
