@@ -23,6 +23,7 @@
  */
 
 #include <QCryptographicHash>
+#include <QNetworkProxy>
 #include <QSslSocket>
 #include <QUrl>
 #include "qdnslookup.h"
@@ -32,7 +33,6 @@
 #include "QXmppIq.h"
 #include "QXmppLogger.h"
 #include "QXmppMessage.h"
-#include "QXmppPacket.h"
 #include "QXmppPresence.h"
 #include "QXmppOutgoingClient.h"
 #include "QXmppStreamFeatures.h"
