@@ -41,15 +41,35 @@
 #include "QXmppServerPlugin.h"
 #include "QXmppUtils.h"
 
-#include "mod_presence.h"
+static void helperToXmlAddDomElement(QXmlStreamWriter* stream, const QDomElement& element, const QStringList &omitNamespaces)
+{
+    stream->writeStartElement(element.tagName());
 
-// Core plugins
-Q_IMPORT_PLUGIN(mod_disco)
-Q_IMPORT_PLUGIN(mod_ping)
-Q_IMPORT_PLUGIN(mod_proxy65)
-Q_IMPORT_PLUGIN(mod_stats)
-Q_IMPORT_PLUGIN(mod_time)
-Q_IMPORT_PLUGIN(mod_version)
+    /* attributes */
+    QString xmlns = element.namespaceURI();
+    if (!xmlns.isEmpty() && !omitNamespaces.contains(xmlns))
+        stream->writeAttribute("xmlns", xmlns);
+    QDomNamedNodeMap attrs = element.attributes();
+    for (int i = 0; i < attrs.size(); i++)
+    {
+        QDomAttr attr = attrs.item(i).toAttr();
+        stream->writeAttribute(attr.name(), attr.value());
+    }
+
+    /* children */
+    QDomNode childNode = element.firstChild();
+    while (!childNode.isNull())
+    {
+        if (childNode.isElement())
+        {
+            helperToXmlAddDomElement(stream, childNode.toElement(), QStringList() << xmlns);
+        } else if (childNode.isText()) {
+            stream->writeCharacters(childNode.toText().data());
+        }
+        childNode = childNode.nextSibling();
+    }
+    stream->writeEndElement();
+}
 
 class QXmppServerPrivate
 {
@@ -103,7 +123,7 @@ QXmppServerPrivate::QXmppServerPrivate(QXmppServer *qq)
 bool QXmppServerPrivate::routeData(const QString &to, const QByteArray &data)
 {
     // refuse to route packets to empty destination, own domain or sub-domains
-    const QString toDomain = jidToDomain(to);
+    const QString toDomain = QXmppUtils::jidToDomain(to);
     if (to.isEmpty() || to == domain || toDomain.endsWith("." + domain))
         return false;
 
@@ -111,7 +131,7 @@ bool QXmppServerPrivate::routeData(const QString &to, const QByteArray &data)
 
         // look for a client connection
         QList<QXmppIncomingClient*> found;
-        if (jidToResource(to).isEmpty()) {
+        if (QXmppUtils::jidToResource(to).isEmpty()) {
             foreach (QXmppIncomingClient *conn, incomingClientsByBareJid.value(to))
                 found << conn;
         } else {
@@ -142,7 +162,7 @@ bool QXmppServerPrivate::routeData(const QString &to, const QByteArray &data)
         // if we did not find an outgoing server,
         // we need to establish the S2S connection
         QXmppOutgoingServer *conn = new QXmppOutgoingServer(domain, 0);
-        conn->setLocalStreamKey(generateStanzaHash().toAscii());
+        conn->setLocalStreamKey(QXmppUtils::generateStanzaHash().toAscii());
         conn->moveToThread(q->thread());
         conn->setParent(q);
 
@@ -237,11 +257,9 @@ void QXmppServerPrivate::warning(const QString &message)
 
 void QXmppServerPrivate::loadExtensions(QXmppServer *server)
 {
-    if (!loaded)
-    {
+    if (!loaded) {
         QObjectList plugins = QPluginLoader::staticInstances();
-        foreach (QObject *object, plugins)
-        {
+        foreach (QObject *object, plugins) {
             QXmppServerPlugin *plugin = qobject_cast<QXmppServerPlugin*>(object);
             if (!plugin)
                 continue;
@@ -249,10 +267,6 @@ void QXmppServerPrivate::loadExtensions(QXmppServer *server)
             foreach (const QString &key, plugin->keys())
                 server->addExtension(plugin->create(key));
         }
-
-        // FIXME: until we can handle presence errors, we need to
-        // keep this extension last.
-        server->addExtension(new QXmppServerPresence);
         loaded = true;
     }
 }
@@ -261,8 +275,7 @@ void QXmppServerPrivate::loadExtensions(QXmppServer *server)
 
 void QXmppServerPrivate::startExtensions()
 {
-    if (!started)
-    {
+    if (!started) {
         foreach (QXmppServerExtension *extension, extensions)
             if (!extension->start())
                 warning(QString("Could not start extension %1").arg(extension->extensionName()));
@@ -275,8 +288,7 @@ void QXmppServerPrivate::startExtensions()
 
 void QXmppServerPrivate::stopExtensions()
 {
-    if (started)
-    {
+    if (started) {
         for (int i = extensions.size() - 1; i >= 0; --i)
             extensions[i]->stop();
         started = false;
@@ -327,6 +339,15 @@ void QXmppServer::addExtension(QXmppServerExtension *extension)
     d->info(QString("Added extension %1").arg(extension->extensionName()));
     extension->setParent(this);
     extension->setServer(this);
+
+    // keep extensions sorted by priority
+    for (int i = 0; i < d->extensions.size(); ++i) {
+        QXmppServerExtension *other = d->extensions[i];
+        if (other->extensionPriority() < extension->extensionPriority()) {
+            d->extensions.insert(i, extension);
+            return;
+        }
+    }
     d->extensions << extension;
 }
 
@@ -617,7 +638,7 @@ void QXmppServer::_q_clientConnected()
         old->disconnectFromHost();
     }
     d->incomingClientsByJid.insert(jid, client);
-    d->incomingClientsByBareJid[jidToBareJid(jid)].insert(client);
+    d->incomingClientsByBareJid[QXmppUtils::jidToBareJid(jid)].insert(client);
 
     // emit signal
     emit clientConnected(jid);
@@ -637,7 +658,7 @@ void QXmppServer::_q_clientDisconnected()
         if (!jid.isEmpty()) {
             if (d->incomingClientsByJid.value(jid) == client)
                 d->incomingClientsByJid.remove(jid);
-            const QString bareJid = jidToBareJid(jid);
+            const QString bareJid = QXmppUtils::jidToBareJid(jid);
             if (d->incomingClientsByBareJid.contains(bareJid)) {
                 d->incomingClientsByBareJid[bareJid].remove(client);
                 if (d->incomingClientsByBareJid[bareJid].isEmpty())
