@@ -45,14 +45,15 @@ class QXmppStream;
 ///
 /// \ingroup Core
 
-class QXmppServerExtension : public QXmppLoggable
+class QXMPP_EXPORT QXmppServerExtension : public QXmppLoggable
 {
     Q_OBJECT
 
 public:
     QXmppServerExtension();
     ~QXmppServerExtension();
-    QString extensionName() const;
+    virtual QString extensionName() const;
+    virtual int extensionPriority() const;
 
     virtual QStringList discoveryFeatures() const;
     virtual QStringList discoveryItems() const;
